
//extend jLinq to search Flickr
jlinq.flickr = function(search, action) {
    search = escape(search);
    $.getJSON(
        "http://api.flickr.com/services/feeds/photos_public.gne?"+
        "tagmode=any&format=json&jsoncallback=?&tags="+search, 
        function(data) {
            var query = jlinq.from(data.items);
            action(query);
        });
};

//create the elements for the view
var flickr = {
    
    //the time to wait before searching the API
    delay:500,
    
    //ui elements, populated at init
    ui:{},
    
    //peform a search and display results
    search:function(text) {
        
        //start a new jLinq query
        jlinq.flickr(text, function(query) {
        
            //clear the previous results
            flickr.ui.results.empty();
            
            //if excluding titles with digits
            if (flickr.ui.filterNumbers.is(":checked")) {
                query.notMatch("title", /\d/g);
            }

            //if requiring a photo to have a title
            if (flickr.ui.requireTitle.is(":checked")) { 
                query.notEmpty("title");
            }

            //if requiring sorting of titles
            if (flickr.ui.sortTitle.is(":checked")) { 
                query.sort("title"); 
            }
            
            //execute the query
            var records = query.select();
            
            //show the results
            var row;
            $.each(records, function(i, rec) {
                
                //check to start a new row
                if (i % 4 == 0 || i == 0) { 
                    row = $("<tr/>").appendTo(results);
                }
                
                //display the cell
                $("<td/>").appendTo(row)
                    .append($("<img/>").attr("src", rec.media.m))
                    .append($("<h4/>").text(rec.title));
            });
        
        });
    
    },
    
    //prepares the flickr search 
    init:function(params) {
    
        //populate content when the page is ready
        $(function() {
        
            //the area to display results
            flickr.ui.results = $(params.results);
        
            //update the text box
            flickr.ui.search = $(params.search);
            
            //create the function to perform searching
            var doSearch = function() {
                window.clearTimeout(flickr.ui.search.pending);
                flickr.ui.search.pending = window.setTimeout(function() {
                    var value = flickr.ui.search.val();
                    flickr.search(value);
                }, flickr.delay);
            };
            
            //assign it for the key presses
            flickr.ui.search.keyup(doSearch);
            
            //update the number filtering
            flickr.ui.filterNumbers = $(params.filterNumbers)
                .change(doSearch);
            
            //update the title requirements
            flickr.ui.requireTitle = $(params.requireTitle)
                .change(doSearch);
            
            //update the sort title box
            flickr.ui.sortTitle = $(params.sortTitle)
                .change(doSearch);
            
        });
    
    }
    
};